//  MenuBar.h version 1.5
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998,1999  Gaspar Sinai
// 
//  yudit version 1.5  Copyright(C) 30 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.4  Copyright(C) 25 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.3  Copyright(C)  5 April,    1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.2  Copyright(C) 10 December, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Gaspar Sinai <gsinai@gol.com>
//

#ifndef ___menubar_h__
#define ___menubar_h__

#include <qobject.h>
#include <qwidget.h>
#include <qmenudata.h>
#include <qkeycode.h>
#include <qmenubar.h>
#include <UFont.h>
#include "Config.h"

//
// Make a menuaction with a menubar widget..
//
class MenuBarAction
{
public:
	virtual int aInsert (const char* text, QPopupMenu*);
};

class MenuBar : public QObject
{
	Q_OBJECT
public:
	enum	SearchType {FIND, GOTO, SEARCHSIZE };
	enum	HelpType { ABOUT, GENERAL, CONFIG, TESTPAGE, HELPSIZE };
				MenuBar	(MenuBarAction* prnt, 
					const Config*  configIn);
				~MenuBar ();
signals:
	void			helpSignal (MenuBar::HelpType type);
	void			searchSignal (MenuBar::SearchType type);
	void 			quitSignal ();
	void 			exitSignal ();
	void 			newSignal ();
	void 			saveAsFile ();
	void 			saveFile ();
	void 			reloadFileSignal ();
	void			loadFileSignal();
	void			configSignal();
	void			printSignal();
	void			appendFileSignal();

	void			changeConfigSignal (Config::CheckList type,
					const char* setTo);	

protected:
	QPopupMenu*		fileMenu;

	// This has cascade buttons only
	QPopupMenu*		windowMenu;

	QPopupMenu*		configMenu[Config::CHECKLIST_MAX];
	int			configMenuId[Config::CHECKLIST_MAX];
	QPopupMenu*		searchMenu;
	QPopupMenu*		helpMenu;
private:
	void 			checkGeneric (Config::CheckList list);
	const Config*		config;

private slots:
	void 			saveFileSlot ();
	void 			saveAsFileSlot ();
	void			loadFileSlot();
	void			reloadFileSlot();
	void			appendFileSlot();
	void 			configSlot ();
	void 			printSlot ();
	void 			quitSlot ();
	void 			exitSlot ();
	void 			newSlot ();

	void 			fontWeightSlot (int i);
	void 			fontSlantSlot (int i);
	void 			fontSizeSlot (int i);
	void 			fontNameSlot (int i);
	void 			fontSpacingSlot (int i);
	void 			fontAddStyleSlot (int i);
	void 			fontAvgWidthSlot (int i);
	void 			inputSlot (int i);
	void 			xInputSlot (int i);
	void 			encodingSlot (int i);
	void			windowForegroundSlot (int i);
	void			windowBackgroundSlot (int i);
	void			tabSizeSlot (int i);
	void			windowCursorColorSlot (int i);
	void			searchFindSlot ();
	void			searchGotoSlot ();
	void			helpAboutSlot ();
	void			helpGeneralSlot ();
	void			helpConfigSlot ();
	void			helpTestPageSlot ();
};

#endif /* __menubar_h__ */
